@@ -13,7 +13,9 @@ from chemsolve.compound import Compound
 from chemsolve.compound import FormulaCompound
 from chemsolve.utils.combustion import determine_main_compound
 from chemsolve.utils.warnings import assert_presence
-from chemsolve.utils.warnings import RemovalWarning
+from chemsolve.utils.warnings import ChemsolveDeprecationWarning
+
+__all__ = ['Reaction', 'CombustionTrain']
 
 try:
    import periodictable as pt
@@ -23,7 +25,7 @@ except ImportError:
    print("The module periodictable could not be found (may have not been installed).")
 
 class Reaction(object):
-   '''
+   """
    Stores a balanced/unbalanced chemical reaction.
 
    INPUTS:
@@ -35,57 +37,62 @@ class Reaction(object):
 
    If you want to use the calculation methods, you have to set the calculation booleans to True.
    Otherwise, it will force you to enter values for the moles/grams of each compound even if you don't have them.
-   '''
+   """
    def __init__(self, *args, lim_calc = False, main_reactant = None, **kwargs):
       self.lim_calc = lim_calc
       self.reactants = []
       self.products = []
       self.original_reaction = ""
-      self.__reactant_store = []
-      self.__product_store = []
-      assert_presence(self.__reactant_store, self.__product_store)
+      self._reactant_store = []
+      self._product_store = []
+      assert_presence(self._reactant_store, self._product_store)
 
-      tempvar = self.reactants
-      tempvar2 = self.__reactant_store
+      temp = self.reactants
+      temp2 = self._reactant_store
       for compound in args:
          if isinstance(compound, str):
             self.original_reaction += str("--> ")
-            tempvar = self.products
-            tempvar2 = self.__product_store
+            temp = self.products
+            temp2 = self._product_store
          else:
-            tempvar2.append(compound)
+            temp2.append(compound)
             self.original_reaction += str(compound.__str__() + " ")
             if compound != args[-1] and not isinstance(args[args.index(compound) + 1], str):
                self.original_reaction += str("+ ")
             if not isinstance(compound, (Element, Compound)):
                raise TypeError("The object " + str(compound) + " is not of type Compound or related subclasses, please redefine it.")
-            else: tempvar.append(compound.__repr__())
+            else: temp.append(compound.__repr__())
 
-      self.__balanced = self.__balance()
+      self._balanced = self._balance()
       self.balanced_reaction = self.balanced_display()
       self.limiting_reactant = self.get_limiting_reactant(self.lim_calc)
       self.coefficient_sum = self.get_coefficient_sum()
 
-      if main_reactant: self.main_reactant = main_reactant
+      if main_reactant:
+         self.main_reactant = main_reactant
 
    def __str__(self):
       return self.original_reaction
 
-   def __call__(self, *args, **kwargs):
-      pass
-      #TODO: Add to this call function.
-
    def __getattr__(self, item):
-      return "The attribute " + str(item) + " does not exist within this class."
+      raise AttributeError("The attribute " + str(item) + " does not exist within the Reaction class.")
+
+   def __contains__(self, item):
+      # Determine if a compound is in the reaction.
+      if isinstance(item, Compound):
+         if item.__repr__() in self.reactants or item.__repr__() in self.products:
+            return True
+      elif isinstance(item, str):
+         if item in self.reactants or item in self.products:
+            return True
+      return False
 
    @classmethod
    def fromCombustion(cls, *args, hydrocarbon = True, othercompound = False, sample_mass = 0.0, **kwargs):
-      '''
+      """
       An implementation of a class method representing a combustion reaction.
-      '''
-      global main_reactant
-
-      if hydrocarbon == False:
+      """
+      if not hydrocarbon:
          if sample_mass == 0.0:
             raise AttributeError("You must provide the total mass of the product in order to determine the quantity of oxygen.")
          else:
@@ -105,70 +112,68 @@ class Reaction(object):
             product_store.append(compound)
             products.append(compound.__repr__())
 
-      if hydrocarbon == True:
-         if othercompound == True:
-            main_reactant = Compound(determine_main_compound(product_store,
-               sample_mass, hydrocarbon = hydrocarbon, othercompound = True)).__repr__()
+      # Calculate main reactant.
+      main_reactant = None
+
+      if hydrocarbon:
+         if othercompound:
+            main_reactant = Compound(determine_main_compound(product_store, sample_mass, hydrocarbon = hydrocarbon,
+                                                             othercompound = True))
          else:
-            main_reactant = Compound(determine_main_compound(product_store, sample_mass, hydrocarbon = hydrocarbon))\
-                           .__repr__()
-      if hydrocarbon == False:
+            main_reactant = Compound(determine_main_compound(product_store, sample_mass,
+                                                             hydrocarbon = hydrocarbon))
+      if not hydrocarbon:
          main_reactant = Compound(determine_main_compound(product_store, sample_mass, hydrocarbon = hydrocarbon),
-                                  grams = sample_mass).__repr__()
+                                  grams = sample_mass)
 
-      return cls(Compound(main_reactant), Compound("O2"), "-->", *product_store, main_reactant = main_reactant)
+      return cls(main_reactant, Compound("O2"), "-->", *product_store, main_reactant = main_reactant)
+
+   @staticmethod
+   def from_combustion(*args, hydrocarbon = True, othercompound = False, sample_mass = 0.0, **kwargs):
+      """A transitional method for v2.0.0, will eventually replace fromCombustion."""
+      return Reaction.fromCombustion(*args, hydrocarbon = hydrocarbon, othercompound = othercompound,
+                                     sample_mass = sample_mass, **kwargs)
 
-   '''
-   Functions which gather attributes.
-   '''
    @property
    def get_reactants(self):
-      '''
-      Returns the reactants of the reaction.
-      '''
+      """Returns the reactants of the reaction."""
       return self._reactants
 
    @property
    def get_products(self):
-      '''
-      Returns the products of the reaction.
-      '''
+      """Returns the products of the reaction."""
       return self._products
 
-   def __balance(self):
-      '''
-      Private method. Returns ordered dictionaries containing the balanced reaction's reactants and products.
-      '''
+   def _balance(self):
+      """Internal method, returns ordered dictionaries containing the balanced reaction's reactants and products."""
       return balance_stoichiometry({f for f in self.reactants}, {f for f in self.products})
 
    def balanced_display(self):
-      '''
-      Returns a displayable version of the balanced reaction.
-      '''
+      """Returns a displayable version of the balanced reaction."""
       tempstr = ""
-      e1 = list(self.__balanced[0].items())
+      e1 = list(self._balanced[0].items())
       count = 0
       for reactant in self.reactants:
          count += 1
-         for item in self.__balanced[0]:
+         for item in self._balanced[0]:
             if str(item) == str(reactant):
-               self.__balanced[0][item] = int(self.__balanced[0][item])
-               if not self.__balanced[0][item] == 1:
-                  tempstr += str(self.__balanced[0][item])
+               self._balanced[0][item] = int(self._balanced[0][item])
+               if not self._balanced[0][item] == 1:
+                  tempstr += str(self._balanced[0][item])
                tempstr += str(Compound(str(item)).__str__()) + str(" ")
                if count < len(e1):
                   tempstr += str("+ ")
       tempstr += str("--> ")
       #----
-      e2 = list(self.__balanced[1].items())
+      e2 = list(self._balanced[1].items())
       count = 0
       for product in self.products:
          count += 1
-         for item in self.__balanced[1]:
+         for item in self._balanced[1]:
             if str(item) == str(product):
-               self.__balanced[1][item] = int(self.__balanced[1][item])
-               if not self.__balanced[1][item] == 1:
-                  tempstr += str(self.__balanced[1][item])
+               self._balanced[1][item] = int(self._balanced[1][item])
+               if not self._balanced[1][item] == 1:
+                  tempstr += str(self._balanced[1][item])
                tempstr += str(Compound(str(item)).__str__()) + str(" ")
                if count < len(e2):
                   tempstr += str("+ ")
@@ -178,43 +183,39 @@ class Reaction(object):
       return tempstr
 
    def get_coefficient_sum(self):
-      '''
-      Returns the sum of the coefficients of the reactants and products in the reaction.
-      '''
+      """Returns the sum of the coefficients of the reactants and products in the reaction."""
       self.coefficient_sum = 0
-      for item in self.__balanced[0]:
-         self.coefficient_sum += int(self.__balanced[0][item])
-      for item in self.__balanced[1]:
-         self.coefficient_sum += int(self.__balanced[1][item])
+      for item in self._balanced[0]:
+         self.coefficient_sum += int(self._balanced[0][item])
+      for item in self._balanced[1]:
+         self.coefficient_sum += int(self._balanced[1][item])
 
       return self.coefficient_sum
 
    def get_limiting_reactant(self, lim_calc = False):
-      '''
-      Returns the limiting reactant of the chemical reaction. Uses the moles/grams values from the Compound objects.
-      '''
-      if lim_calc == True:
-         lim_reac = Compound
-         quant = sys.maxsize
-         product = (next(iter((self.__balanced[1]).items())))[1]
+      """Returns the limiting reactant of the chemical reaction. Uses the moles/grams values from the Compound objects."""
+      if lim_calc:
+         lim_reac = None
+         product = (next(iter((self._balanced[1]).items())))[1]
          moles = 0
          org_moles = 0
 
-         for item in list((self.__balanced[0]).items()):
-            for com in self.__reactant_store:
+         for item in list((self._balanced[0]).items()):
+            for com in self._reactant_store:
                if Compound(item[0]).__str__() == com.__str__():
                   moles = com.mole_amount
                   org_moles = moles
             moles *= operator.truediv(product, item[1])
-            if moles < quant:
+            if moles < sys.maxsize:
                lim_reac = item[0]
 
          return Compound(lim_reac, moles = org_moles)
       else:
          return False
 
-class CombustionTrain(Reaction): #TODO: Will be deprecated in a future version.
-   '''
+@ChemsolveDeprecationWarning('CombustionTrain', future_version ='2.0.0')
+class CombustionTrain(Reaction):
+   """
    Determines an unknown compound in a combustion reaction.
 
    Used in a combustion reaction, when knowing the mass of the initial compound(made up of C, H, and O),
@@ -232,14 +233,13 @@ class CombustionTrain(Reaction): #TODO: Will be deprecated in a future version.
    **You must enter the products in the order: CO2, H2O, <other element/compound>.
 
    The limiting reactant will always be assumed to be the non-oxygen reactant, as with most calculated
-   combustion reaction.
+   combustion reactions.
 
    **This class only determines the reacting compound, so DO NOT use this class for a regular reaction.
-   '''
+   """
    def __init__(self, *args, hydrocarbon = True, othercompound = False, sample_mass = 0.0, **kwargs):
-      RemovalWarning(future_version = "2.0.0")
       # A lot of errors may arise, all need to be prevented.
-      if hydrocarbon == False:
+      if not hydrocarbon:
          if sample_mass == 0.0:
             raise AttributeError("You must provide the total mass of the product in order to determine the quantity of oxygen.")
          else:
@@ -252,20 +252,21 @@ class CombustionTrain(Reaction): #TODO: Will be deprecated in a future version.
       for compound in args:
          try:
             compound.mass
-         except AttributeError as exception:
-            print("You must provide the masses of the compounds as acquired in the Compound definition.")
-            raise exception
+         except AttributeError:
+            raise AttributeError("You must provide the masses of the compounds as acquired in the Compound definition.")
+         except Exception as e:
+            raise e
          else:
             self.__product_store.append(compound)
             self.products.append(compound.__repr__())
 
-      if hydrocarbon == True:
-         if othercompound == True:
+      if hydrocarbon:
+         if othercompound:
             self.main_reactant = Compound(self.determine_main_compound(
                sample_mass, hydrocarbon = hydrocarbon, othercompound = True))
          else:
             self.main_reactant = Compound(self.determine_main_compound(sample_mass, hydrocarbon = hydrocarbon))
-      if hydrocarbon == False:
+      if not hydrocarbon:
          self.main_reactant = Compound(self.determine_main_compound(sample_mass, hydrocarbon = hydrocarbon), grams = sample_mass)
 
       if len(args) == 2:
@@ -282,12 +283,11 @@ class CombustionTrain(Reaction): #TODO: Will be deprecated in a future version.
       __hold = []
       other = None
 
-      #TODO: Add functionality for giving the other compound but not its mass, and having to calculate that.
-      #-------------------
+      # POTENTIAL: Add functionality for giving the other compound but not its mass, and having to calculate that.
       # other_calc = False
 
-      if hydrocarbon == False and othercompound == True:
-            raise ValueError("You cannot have a hydrocarbon that also contains another element.")
+      if not hydrocarbon and othercompound:
+         raise ValueError("You cannot have a hydrocarbon that also contains another element.")
       for index, compound in enumerate(self.__product_store):
          if 'O' not in compound.__repr__() and not isinstance(compound, (Element, SpecialElement)):
             raise TypeError("The CombustionTrain class only takes in oxide compounds or elements.")
@@ -307,8 +307,8 @@ class CombustionTrain(Reaction): #TODO: Will be deprecated in a future version.
                mole_val.append(compound.mole_amount)
             __hold.append(other)
 
-      if hydrocarbon == True:
-         if other == None:
+      if hydrocarbon:
+         if other is None:
             reactant = FormulaCompound(SpecialElement('C', moles = mole_val[0]), SpecialElement('H', moles = mole_val[1]))\
                        .empirical.__repr__()
             self.main_reactant = reactant
@@ -317,11 +317,11 @@ class CombustionTrain(Reaction): #TODO: Will be deprecated in a future version.
                                        SpecialElement(other, moles = mole_val[2])).empirical.__repr__()
             self.main_reactant = reactant
 
-      if hydrocarbon == False:
+      if not hydrocarbon:
          e1 = mole_val[0] * Element('C').mass
          e2 = mole_val[1] * Element('H').mass
          reactant = None
-         if other == None:
+         if other is None:
             e3 = sample_mass - e1 - e2
             mole_val.append(operator.truediv(e3, Element('O').mass))
 
